@@ -26,19 +26,24 @@ def faceRecognizer(filepath):
     # cv2.namedWindow('recognizer')
     # OpenCV人脸识别分类器
     classifier_default = cv2.CascadeClassifier(
-        "haarcascades/haarcascade_frontalface_default.xml"
+        #"haarcascades/haarcascade_frontalface_default.xml"
+        "haarcascade_frontalface_default.xml"
     )
     classifier_alt_tree = cv2.CascadeClassifier(
-        "haarcascades/haarcascade_frontalface_alt_tree.xml"
+        # "haarcascades/haarcascade_frontalface_alt_tree.xml"
+        "haarcascade_frontalface_alt_tree.xml"
     )
     classifier_alt2 = cv2.CascadeClassifier(
-        "haarcascades/haarcascade_frontalface_alt2.xml"
+        #"haarcascades/haarcascade_frontalface_alt2.xml"
+        "haarcascade_frontalface_alt2.xml"
     )
     classifier_alt = cv2.CascadeClassifier(
-        "haarcascades/haarcascade_frontalface_alt.xml"
+        #"haarcascades/haarcascade_frontalface_alt.xml"
+        "haarcascade_frontalface_alt.xml"
     )
     classifier_ce = cv2.CascadeClassifier(
-        "haarcascades/haarcascade_profileface.xml"
+        #"haarcascades/haarcascade_profileface.xml"
+        "haarcascade_profileface.xml"
     )
     color = (0, 0, 255)  # 定义绘制颜色
     # 调用识别人脸
